// Modules to control application life and create native browser window
const { app, BrowserWindow } = require('electron')
const path = require('node:path')


const Store = require('electron-store');
const { url } = require('node:inspector');
const store = new Store();

// /home/user/.config/appname
console.log(app.getPath('userData'));

store.set('unicorn', '🦄');
console.log(store.get('unicorn'));
//=> '🦄'

let target_url = undefined
try {
  // (if any) We load the URLs
  let url_list = store.get('url_list')
  url_list = JSON.parse(url_list)
  // (if any) We load the index
  let index_url = store.get('index_url')
  // (if possible) We load the indexed URL
  target_url = url_list[index_url]
} catch (error) {
  //console.log(error)
  target_url = store.get('target_url')
}
console.log(target_url);

function createWindow () {
  // Create the browser window.
  const mainWindow = new BrowserWindow({
    width: 800,
    height: 600,
    webPreferences: {
    }
  })

  // and load the index.html of the app.
  if (target_url || target_url === "base") {
   mainWindow.loadURL(target_url)
  } else {
    mainWindow.loadFile('index.html')
  }

  // Open the DevTools.
  // mainWindow.webContents.openDevTools()
}

// This method will be called when Electron has finished
// initialization and is ready to create browser windows.
// Some APIs can only be used after this event occurs.
app.whenReady().then(() => {
  createWindow()

  app.on('activate', function () {
    // On macOS it's common to re-create a window in the app when the
    // dock icon is clicked and there are no other windows open.
    if (BrowserWindow.getAllWindows().length === 0) createWindow()
  })
})

// Quit when all windows are closed, except on macOS. There, it's common
// for applications and their menu bar to stay active until the user quits
// explicitly with Cmd + Q.
app.on('window-all-closed', function () {
  if (process.platform !== 'darwin') app.quit()
})

// In this file you can include the rest of your app's specific main process
// code. You can also put them in separate files and require them here.
